pub struct FloatingPoint<'st, const EB: usize, const SB: usize>(/* private fields */);Expand description
A floating-point number, parameterized by exponent bits (EB) and significand bits (SB). Significand bits include the sign bit.
Implementations
Sourceimpl<'st, const EB: usize, const SB: usize> FloatingPoint<'st, EB, SB>
impl<'st, const EB: usize, const SB: usize> FloatingPoint<'st, EB, SB>
Sourcepub fn new(
st: &'st Storage,
value: impl IntoWithStorage<'st, FloatingPoint<'st, EB, SB>>,
) -> FloatingPoint<'st, EB, SB>
pub fn new( st: &'st Storage, value: impl IntoWithStorage<'st, FloatingPoint<'st, EB, SB>>, ) -> FloatingPoint<'st, EB, SB>
Construct a new bit-vec.
Sourcepub fn fp<const SB_1: usize>(
st: &'st Storage,
sign: BitVec<'st, 1>,
exponent: BitVec<'st, EB>,
significand: BitVec<'st, SB_1>,
) -> Self
pub fn fp<const SB_1: usize>( st: &'st Storage, sign: BitVec<'st, 1>, exponent: BitVec<'st, EB>, significand: BitVec<'st, SB_1>, ) -> Self
Creates a floating-point value from sign, exponent, and significand
bit-vectors. i = sb - 1
Note: The SB_1 parameter is a workaround for
#![feature(generic_const_exprs)].
Sourcepub fn minus_zero(st: &'st Storage) -> Self
pub fn minus_zero(st: &'st Storage) -> Self
Negative zero
Sourcepub fn fp_add(self, rm: RoundingMode<'st>, other: Self) -> Self
pub fn fp_add(self, rm: RoundingMode<'st>, other: Self) -> Self
Addition (fp.add)
Sourcepub fn fp_sub(self, rm: RoundingMode<'st>, other: Self) -> Self
pub fn fp_sub(self, rm: RoundingMode<'st>, other: Self) -> Self
Subtraction (fp.sub)
Sourcepub fn fp_mul(self, rm: RoundingMode<'st>, other: Self) -> Self
pub fn fp_mul(self, rm: RoundingMode<'st>, other: Self) -> Self
Multiplication (fp.mul)
Sourcepub fn fp_div(self, rm: RoundingMode<'st>, other: Self) -> Self
pub fn fp_div(self, rm: RoundingMode<'st>, other: Self) -> Self
Division (fp.div)
Sourcepub fn fp_fma(self, rm: RoundingMode<'st>, other1: Self, other2: Self) -> Self
pub fn fp_fma(self, rm: RoundingMode<'st>, other1: Self, other2: Self) -> Self
Fused multiplication and addition: (self * other1) + other2 (fp.fma)
Sourcepub fn fp_sqrt(self, rm: RoundingMode<'st>) -> Self
pub fn fp_sqrt(self, rm: RoundingMode<'st>) -> Self
Square root (fp.sqrt)
Sourcepub fn fp_rem(self, other: Self) -> Self
pub fn fp_rem(self, other: Self) -> Self
Remainder: self - other * n, where n in Z is nearest to self/other
(fp.rem)
Sourcepub fn fp_round_to_integral(self, rm: RoundingMode<'st>) -> Self
pub fn fp_round_to_integral(self, rm: RoundingMode<'st>) -> Self
Rounding to integral (fp.roundToIntegral)
Sourcepub fn fp_is_normal(self) -> Bool<'st>
pub fn fp_is_normal(self) -> Bool<'st>
Is normal (fp.isNormal)
Sourcepub fn fp_is_subnormal(self) -> Bool<'st>
pub fn fp_is_subnormal(self) -> Bool<'st>
Is subnormal (fp.isSubnormal)
Sourcepub fn fp_is_zero(self) -> Bool<'st>
pub fn fp_is_zero(self) -> Bool<'st>
Is zero (fp.isZero)
Sourcepub fn fp_is_infinite(self) -> Bool<'st>
pub fn fp_is_infinite(self) -> Bool<'st>
Is infinite (fp.isInfinite)
Sourcepub fn fp_is_negative(self) -> Bool<'st>
pub fn fp_is_negative(self) -> Bool<'st>
Is negative (fp.isNegative)
Sourcepub fn fp_is_positive(self) -> Bool<'st>
pub fn fp_is_positive(self) -> Bool<'st>
Is positive (fp.isPositive)
Sourcepub fn to_fp_from_bits<const M: usize>(
st: &'st Storage,
bv: BitVec<'st, M>,
) -> Self
pub fn to_fp_from_bits<const M: usize>( st: &'st Storage, bv: BitVec<'st, M>, ) -> Self
From single bitstring representation in IEEE 754-2008 interchange
format. M = EB + SB (to_fp)
Sourcepub fn to_fp_from_fp<const MB: usize, const NB: usize>(
st: &'st Storage,
rm: RoundingMode<'st>,
fp_other: FloatingPoint<'st, MB, NB>,
) -> Self
pub fn to_fp_from_fp<const MB: usize, const NB: usize>( st: &'st Storage, rm: RoundingMode<'st>, fp_other: FloatingPoint<'st, MB, NB>, ) -> Self
From another floating point sort (to_fp)
Sourcepub fn to_fp_from_real(
st: &'st Storage,
rm: RoundingMode<'st>,
real: Real<'st>,
) -> Self
pub fn to_fp_from_real( st: &'st Storage, rm: RoundingMode<'st>, real: Real<'st>, ) -> Self
From real (to_fp)
Sourcepub fn to_fp_from_signed_bit_vec<const M: usize>(
st: &'st Storage,
rm: RoundingMode<'st>,
bv: BitVec<'st, M>,
) -> Self
pub fn to_fp_from_signed_bit_vec<const M: usize>( st: &'st Storage, rm: RoundingMode<'st>, bv: BitVec<'st, M>, ) -> Self
From signed machine integer, represented as a 2’s complement bit vector
(to_fp)
Sourcepub fn to_fp_from_unsigned_bit_vec<const M: usize>(
st: &'st Storage,
rm: RoundingMode<'st>,
bv: BitVec<'st, M>,
) -> Self
pub fn to_fp_from_unsigned_bit_vec<const M: usize>( st: &'st Storage, rm: RoundingMode<'st>, bv: BitVec<'st, M>, ) -> Self
From unsigned machine integer, represented as bit vector
(to_fp_unsigned)
Sourcepub fn fp_to_ubv<const M: usize>(self, rm: RoundingMode<'st>) -> BitVec<'st, M>
pub fn fp_to_ubv<const M: usize>(self, rm: RoundingMode<'st>) -> BitVec<'st, M>
To unsigned machine integer, represented as a bit vector (fp.to_ubv)
Sourcepub fn fp_to_sbv<const M: usize>(self, rm: RoundingMode<'st>) -> BitVec<'st, M>
pub fn fp_to_sbv<const M: usize>(self, rm: RoundingMode<'st>) -> BitVec<'st, M>
To signed machine integer, represented as a 2’s complement bit vector
(fp.to_sbv)
Sourcepub fn fp_to_real(self) -> Real<'st>
pub fn fp_to_real(self) -> Real<'st>
To real (fp.to_real)